==> kubernetes-model-networking-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1/NetworkPolicyPortFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import java.lang.String;
import com.fasterxml.jackson.databind.JsonDeserializer;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.lang.Deprecated;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import com.fasterxml.jackson.core.JsonParser;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Object;
import java.util.Map;

public interface NetworkPolicyPortFluent<A extends NetworkPolicyPortFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public IntOrString getPort();
    public IntOrString buildPort();
    public A withPort(IntOrString port);
    public Boolean hasPort();
    public A withNewPort(String strVal);
    public A withNewPort(Integer intVal);
    public NetworkPolicyPortFluent.PortNested<A> withNewPort();
    public NetworkPolicyPortFluent.PortNested<A> withNewPortLike(IntOrString item);
    public NetworkPolicyPortFluent.PortNested<A> editPort();
    public NetworkPolicyPortFluent.PortNested<A> editOrNewPort();
    public NetworkPolicyPortFluent.PortNested<A> editOrNewPortLike(IntOrString item);
    public String getProtocol();
    public A withProtocol(String protocol);
    public Boolean hasProtocol();
    public A withNewProtocol(StringBuilder arg1);
    public A withNewProtocol(int[] arg1,int arg2,int arg3);
    public A withNewProtocol(char[] arg1);
    public A withNewProtocol(StringBuffer arg1);
    public A withNewProtocol(byte[] arg1,int arg2);
    public A withNewProtocol(byte[] arg1);
    public A withNewProtocol(char[] arg1,int arg2,int arg3);
    public A withNewProtocol(byte[] arg1,int arg2,int arg3);
    public A withNewProtocol(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewProtocol(String arg1);
    public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IntOrStringFluent<NetworkPolicyPortFluent.PortNested<N>> {

            public N and();
            public N endPort();    }


}

==> kubernetes-model-networking-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1/NetworkPolicyPortFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import java.lang.String;
import com.fasterxml.jackson.databind.JsonDeserializer;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.lang.Deprecated;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.JsonParser;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.io.IOException;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Object;
import java.util.Map;

public interface NetworkPolicyPortFluent<A extends NetworkPolicyPortFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public IntOrString getPort();
    public IntOrString buildPort();
    public A withPort(IntOrString port);
    public Boolean hasPort();
    public A withNewPort(String strVal);
    public A withNewPort(Integer intVal);
    public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPortFluent.PortNested<A> withNewPort();
    public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPortFluent.PortNested<A> withNewPortLike(IntOrString item);
    public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPortFluent.PortNested<A> editPort();
    public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPortFluent.PortNested<A> editOrNewPort();
    public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPortFluent.PortNested<A> editOrNewPortLike(IntOrString item);
    public String getProtocol();
    public A withProtocol(String protocol);
    public Boolean hasProtocol();
    public A withNewProtocol(StringBuilder arg1);
    public A withNewProtocol(int[] arg1,int arg2,int arg3);
    public A withNewProtocol(char[] arg1);
    public A withNewProtocol(StringBuffer arg1);
    public A withNewProtocol(byte[] arg1,int arg2);
    public A withNewProtocol(byte[] arg1);
    public A withNewProtocol(char[] arg1,int arg2,int arg3);
    public A withNewProtocol(byte[] arg1,int arg2,int arg3);
    public A withNewProtocol(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewProtocol(String arg1);
    public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IntOrStringFluent<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPortFluent.PortNested<N>> {

            public N and();
            public N endPort();    }


}
